module Dhatu
  class BookingsController < ResourceController

    def show
      @booking = @r_object = Dhatu::Booking.find_by_id(params[:id])
      if @booking
        @booking.read! if @booking.new? || @booking.unread?
      else
        set_notification(false, I18n.t('status.error'), I18n.t('status.not_found', item: default_item_name.titleize))
      end
    end

    private

    def get_collections
      @new_bookings_count = Dhatu::Booking.new_ones.count
      @unread_bookings_count = Dhatu::Booking.unread.count
      @read_bookings_count = Dhatu::Booking.read.count
      @relation = Dhatu::Booking.where("")
      params[:st] = "new" if params[:st].nil? && params[:q].nil?
      parse_filters
      apply_filters
      @bookings = @r_objects = @relation.page(@current_page).per(@per_page)
      return true
    end

    def apply_filters
      @relation = @relation.search(@query) if @query
      @relation = @relation.status(@status) if @status
      @relation = @relation.order("created_at DESC")
    end

    def configure_filter_settings
      @filter_settings = {
        string_filters: [
          { filter_name: :query },
          { filter_name: :status }
        ],

        boolean_filters: [],
        reference_filters: [],
        variable_filters: [],
      }
    end

    def configure_filter_ui_settings
      @filter_ui_settings = {
        status: {
          object_filter: false,
          select_label: "Filter by Status",
          display_hash: Dhatu::Booking::STATUS_REVERSE,
          current_value: @status,
          values: Dhatu::Booking::STATUS,
          current_filters: @filters,
          filters_to_remove: [],
          filters_to_add: {},
          url_method_name: 'bookings_url',
          show_all_filter_on_top: true
        }
      }
    end

    def resource_controller_configuration
      {
        page_title: "Bookings",
        current_nav: "dhatu/bookings",

        # Resource Names
        class: Dhatu::Booking,
        collection_name: :bookings,
        item_name: :booking,
        
        # Conditions
        get_collections_after_save_resource: false,
        show_modal_after_create: true,
        show_modal_after_update: true,

        # Model Size can be large or generic
        form_model_size: :large,
        show_model_size: :large,

        # Layout can be table or feed
        # table uses html tables and feed uses div based boxes
        layout: :table,

        # "/kuppayam/workflows/default"
        # 
        # Default partial opens show and form partial according to the model_size configuration
        # It also respect the configuration layout and refresh the page element on both cases - i.e layout is table or feed

        # "/kuppayam/workflows/peacock"
        # "/kuppayam/workflows/parrot"
        # 
        # Peacock & Parrot are old ways of doing things and it respects certail configurations
        # Peacock opens show and form partials in large popup where as Parrot opens it in small
        # Both Peacock and Parrot expect table based layout and will reload a single row after create / update

        # Rendering Paths
        view_path: "dhatu/bookings",
        js_view_path: "/kuppayam/workflows/default",

        # Additional Configurations
        load_rich_text_editor: true,
        tagsinput: false
      }
    end

    def breadcrumbs_configuration
      {
        heading: "Manage Bookings",
        icon: "fa-calendar",
        description: "Listing all Bookings",
        links: [{name: "Dashboard", link: breadcrumb_home_path, icon: 'fa-dashboard'}, 
                  {name: "Manage Bookings", link: dhatu.bookings_path, icon: 'fa-calendar', active: true}]
      }
    end

    def set_navs
      set_nav("dhatu/bookings")
    end

  end
end
