module Dhatu
  class BranchesController < ResourceController

    before_action :require_update_permission, only: [:update, :update_status, :mark_as_featured, :remove_from_featured, :make_main, :remove_main]
    
    def make_main
      @branch = @r_object = Dhatu::Branch.find_by_id(params[:id])
      if @branch
        @r_object.update_attribute(:main_branch, true)
        if @r_object.errors.blank?
          set_notification(true, I18n.t('status.success'), I18n.t('state.changed', item: default_item_name.titleize, new_state: @r_object.main_branch))
        else
          set_notification(false, I18n.t('status.error'), @r_object.errors.full_messages.join("<br>"))
        end
      else
        set_notification(false, I18n.t('status.not_found'), I18n.t('status.not_found', item: default_item_name.titleize))
      end
      render_row
    end

    def remove_main
      @branch = @r_object = Dhatu::Branch.find_by_id(params[:id])
      if @branch
        @r_object.update_attribute(:main_branch, false)
        if @r_object.errors.blank?
          set_notification(true, I18n.t('status.success'), I18n.t('state.changed', item: default_item_name.titleize, new_state: @r_object.main_branch))
        else
          set_notification(false, I18n.t('status.error'), @r_object.errors.full_messages.join("<br>"))
        end
      else
        set_notification(false, I18n.t('status.not_found'), I18n.t('status.not_found', item: default_item_name.titleize))
      end
      render_row
    end

    private

    def permitted_params
      params.require("dhatu/branch").permit(:main_branch, :title, :address_1, :address_2, :address_3, :email, :landline, :fax, :mobile, :facebook, :twitter, :google_plus, :linked_in, :youtube, :instagram, :tumblr, :pinterest, :blog)
    end

    def get_collections
      @relation = Dhatu::Branch.where("")
      # params[:st] = "published" if params[:st].nil?
      parse_filters
      apply_filters
      @branches = @r_objects = @relation.page(@current_page).per(@per_page)
      return true
    end

    def apply_filters
      @relation = @relation.search(@query) if @query
      @relation = @relation.status(@status) if @status
      
      @order_by = "created_at desc" unless @order_by
      @relation = @relation.order(@order_by)
    end

    def configure_filter_settings
      @filter_settings = {
        string_filters: [
          { filter_name: :query },
          { filter_name: :status }
        ],

        boolean_filters: [],

        reference_filters: [],
        variable_filters: [],
      }
    end

    def configure_filter_ui_settings
      @filter_ui_settings = {
        status: {
          object_filter: false,
          select_label: "Filter by Status",
          display_hash: Dhatu::Branch::STATUS_REVERSE,
          current_value: @status,
          values: Dhatu::Branch::STATUS,
          current_filters: @filters,
          filters_to_remove: [],
          filters_to_add: {},
          url_method_name: 'branches_url',
          show_all_filter_on_top: true
        }
      }
    end

    def resource_controller_configuration
      {
        page_title: "Manage Branchs",
        current_nav: "dhatu/branches",

        # Resource Names
        class: Dhatu::Branch,
        collection_name: :branches,
        item_name: :branch,
        
        # Conditions
        get_collections_after_save_resource: false,
        show_modal_after_create: true,
        show_modal_after_update: true,

        # Model Size can be large or generic
        form_model_size: :large,
        show_model_size: :large,

        # Layout can be table or feed
        # table uses html tables and feed uses div based boxes
        layout: :table,

        # "/kuppayam/workflows/default"
        # 
        # Default partial opens show and form partial according to the model_size configuration
        # It also respect the configuration layout and refresh the page element on both cases - i.e layout is table or feed

        # "/kuppayam/workflows/peacock"
        # "/kuppayam/workflows/parrot"
        # 
        # Peacock & Parrot are old ways of doing things and it respects certail configurations
        # Peacock opens show and form partials in large popup where as Parrot opens it in small
        # Both Peacock and Parrot expect table based layout and will reload a single row after create / update

        # Rendering Paths
        view_path: "dhatu/branches",
        js_view_path: "/kuppayam/workflows/default",

        # Additional Configurations
        load_rich_text_editor: false,
        tagsinput: false
      }
    end

    def breadcrumbs_configuration
      {
        heading: "Manage Branches",
        icon: "fa-phone-square",
        description: "Listing all Branches",
        links: [{name: "Dashboard", link: breadcrumb_home_path, icon: 'fa-dashboard'}, 
                  {name: "Manage Branches", link: dhatu.branches_path, icon: 'fa-phone-square', active: true}]
      }
    end

    def set_navs
      set_nav("dhatu/branches")
    end

  end
end
