module Dhatu
  class MetaTagsController < ResourceController

    before_action :require_site_admin
    before_action :initialize_row_partial_locals, :get_meta_taggable
    
    def create
      @meta_tag = @r_object = Dhatu::MetaTag.new
      @meta_tag.assign_attributes(permitted_params)
      @meta_tag.meta_taggable = @meta_taggable
      save_resource
    end

    private

    def initialize_row_partial_locals
      @row_partial_locals = {}
    end

    def get_meta_taggable
      if params[:meta_taggable_type] && params[:meta_taggable_id]
        @meta_taggable = params[:meta_taggable_type].constantize.find_by_id(params[:meta_taggable_id])
        @row_partial_locals[:meta_taggable] = @meta_taggable
      end
    end

    def get_collections
      @relation = @meta_taggable.meta_tags.where("")

      parse_filters
      apply_filters

      @meta_tags = @r_objects = @relation.page(@current_page).per(@per_page)
      @row_partial_locals[:meta_tags] = @meta_tags

      return true
    end

    def apply_filters
      @relation = @relation.search(@query) if @query
      
      @order_by = "meta_key ASC" unless @order_by
      @relation = @relation.order(@order_by)
    end

    def configure_filter_settings
      @filter_settings = {
        string_filters: [
          { filter_name: :query }
        ],
        boolean_filters: [],
        reference_filters: [],
        variable_filters: [],
      }
    end

    def configure_filter_ui_settings
      @filter_ui_settings = {}
    end

    def resource_url(obj)
      url_for(obj)
    end

    def resource_controller_configuration
      {
        collection_name: :meta_tags,
        item_name: :meta_tag,
        class: Dhatu::MetaTag,
        feature_class: Dhatu::Page,
        show_modal_after_create: false,
        show_modal_after_update: false,
        page_title: "Manage Meta Tags",
        js_view_path: "/kuppayam/workflows/parrot",
        view_path: "/dhatu/meta_tags"
      }
    end

    def breadcrumbs_configuration
      {
        heading: "Manage Meta Tags",
        description: "Listing Meta Tags for the Page",
        links: [{name: "Home", link: breadcrumb_home_path, icon: 'fa-home'}]
      }
    end

    def permitted_params
      params.require("dhatu/meta_tag").permit(:meta_type, :meta_key, :meta_value)
    end

    def set_navs
      set_nav("admin/meta_tags")
    end

  end
end
