module Dhatu
  class PagesController < ResourceController

    def new
      @r_object = @page = Dhatu::Page.new
      render_accordingly
    end

    private

    def permitted_params
      params.require("dhatu/page").permit(:name, :code, :feature_id, :priority)
    end

    def get_collections
      @relation = Dhatu::Page.includes(:og_image).where("")
      parse_filters
      apply_filters
      @pages = @r_objects = @relation.page(@current_page).per(@per_page)
      return true
    end

    def apply_filters
      @relation = @relation.search(@query) if @query
      @relation = @relation.status(@status) if @status
      @relation = @relation.where("feature_id = ?", @feature.id) if @feature
      @order_by = "priority ASC, created_at desc" unless @order_by
      @relation = @relation.order(@order_by)
    end

    def configure_filter_settings
      @filter_settings = {
        string_filters: [
          { filter_name: :query },
          { filter_name: :status }
        ],
        boolean_filters: [],
        reference_filters: [
          { filter_name: :feature, filter_class: Feature },
        ],
        variable_filters: [],
      }
    end

    def configure_filter_ui_settings
      @filter_ui_settings = {
        status: {
          object_filter: false,
          select_label: "Filter by Status",
          display_hash: Dhatu::Page::STATUS,
          current_value: @status,
          values: Dhatu::Page::STATUS_REVERSE,
          current_filters: @filters,
          filters_to_remove: [],
          filters_to_add: {},
          url_method_name: 'pages_url',
          show_all_filter_on_top: true
        },
        feature: {
          object_filter: true,
          select_label: 'Select Feature',
          current_value: @feature,
          values: Feature.published.order(:name).all,
          current_filters: @filters,
          url_method_name: 'permissions_url',
          filters_to_remove: [:feature],
          filters_to_add: { user: @user.try(:id) },
          show_null_filter_on_top: false,
          show_all_filter_on_top: true
        }
      }
    end

    def resource_controller_configuration
      {
        page_title: "Manage Pages",
        current_nav: "dhatu/pages",

        # Resource Names
        class: Dhatu::Page,
        collection_name: :pages,
        item_name: :page,
        
        # Conditions
        get_collections_after_save_resource: false,
        show_modal_after_create: false,
        show_modal_after_update: false,

        # Model Size can be large or generic
        form_model_size: :generic,
        show_model_size: :large,

        # Layout can be table or feed
        # table uses html tables and feed uses div based boxes
        layout: :feed,

        # "/kuppayam/workflows/default"
        # 
        # Default partial opens show and form partial according to the model_size configuration
        # It also respect the configuration layout and refresh the page element on both cases - i.e layout is table or feed

        # "/kuppayam/workflows/peacock"
        # "/kuppayam/workflows/parrot"
        # 
        # Peacock & Parrot are old ways of doing things and it respects certail configurations
        # Peacock opens show and form partials in large popup where as Parrot opens it in small
        # Both Peacock and Parrot expect table based layout and will reload a single row after create / update

        # Rendering Paths
        view_path: "dhatu/pages",
        js_view_path: "/kuppayam/workflows/default",

        # Additional Configurations
        load_rich_text_editor: false,
        tagsinput: false
      }
    end

    def breadcrumbs_configuration
      {
        heading: "Manage Pages",
        icon: "fa-file",
        description: "Listing all Pages",
        links: [{name: "Dashboard", link: breadcrumb_home_path, icon: 'fa-dashboard'}, 
                  {name: "Manage Pages", link: dhatu.pages_path, icon: 'fa-file', active: true}]
      }
    end

  end
end
