module Dhatu
  class PhotoAlbumsController < ResourceController
    
    before_action :require_update_permission, only: [:update_status, :make_parent, :mark_as_featured, :remove_from_featured]

    def choose_category_type
    end

    def update_status
      @photo_album = @r_object = Dhatu::PhotoAlbum.find(params[:id])
      case params[:status]
      when "unpublished"
        @photo_album.unpublish!
      when "removed"
        @photo_album.remove!
      when "published"
        @photo_album.publish!
      end
      set_notification(true, I18n.t('status.success'), I18n.t('state.changed', item: default_item_name.titleize, new_state: @r_object.status))
      render_row
    end

    def make_parent
      @photo_album = @r_object = Dhatu::PhotoAlbum.find(params[:id])
      @photo_album.update_attribute(:parent_id, nil)
      get_collections
      render_accordingly
    end

    def mark_as_featured
      @photo_album = @r_object = Dhatu::PhotoAlbum.find(params[:id])
      @photo_album.published?
      render_row
    end

    def remove_from_featured
      @photo_album = @r_object = Dhatu::PhotoAlbum.find(params[:id])
      @photo_album.featured?
      render_row
    end

    private

    def save_resource
      if @r_object.valid?
        previous_parent_id = @r_object.parent_id_was
        @r_object.save
        if @r_object.parent_id != previous_parent_id
          @r_object.parent.set_end_node! if @r_object.parent
          previous_category = Dhatu::PhotoAlbum.find_by_id(previous_parent_id)
          previous_category.set_end_node! if previous_category
        end
        @current_photo_album = @r_object.parent
        get_collections if @resource_options[:get_collections_after_save_resource]
        set_flash_message(I18n.translate("forms.save", item: default_item_name.titleize), :success) 
      end
      set_resource_notification(@r_object)
      action_name = params[:action].to_s == "create" ? "new" : "edit"
      url = @r_object.persisted? ? resource_url(@r_object) : nil
      render_or_redirect(@r_object.errors.any?, url, action_name)
    end

    def get_collections

      @current_album = Dhatu::PhotoAlbum.find_by_id(params[:parent_id])

      filter_param_mapping

      parse_filters

      if @current_album
        @relation = @current_album.sub_albums.includes(:parent)
      else
        @relation = Dhatu::PhotoAlbum.where("parent_id IS NULL")
      end

      apply_filters

      @relation = @relation.order("priority ASC, name ASC")
      
      @photo_albums = @r_objects = @relation.page(@current_page).per(@per_page)
      return true
    end

    def apply_filters
      @relation = @relation.search(@query) if @query
      @relation = @relation.status(@status) if @status
    end

    def configure_filter_settings
      @filter_settings = {
        boolean_filters: [
          { filter_name: :featured }
        ],
        string_filters: [
          { filter_name: :query },
          { filter_name: :status }
        ],
        reference_filters: [
          { filter_name: :feature, filter_class: Feature },
        ],
        variable_filters: [],
      }
    end

    def resource_controller_configuration
      {
        page_title: "Manage Photo Albums",
        current_nav: "dhatu/photo_albums",

        # Resource Names
        class: Dhatu::PhotoAlbum,
        collection_name: :photo_albums,
        item_name: :photo_album,
        
        # Conditions
        get_collections_after_save_resource: true,
        show_modal_after_create: false,
        show_modal_after_update: true,

        # Model Size can be large or generic
        form_model_size: :generic,
        show_model_size: :large,

        # Layout can be table or feed
        # table uses html tables and feed uses div based boxes
        layout: :feed,

        # "/kuppayam/workflows/default"
        # 
        # Default partial opens show and form partial according to the model_size configuration
        # It also respect the configuration layout and refresh the page element on both cases - i.e layout is table or feed

        # "/kuppayam/workflows/peacock"
        # "/kuppayam/workflows/parrot"
        # 
        # Peacock & Parrot are old ways of doing things and it respects certail configurations
        # Peacock opens show and form partials in large popup where as Parrot opens it in small
        # Both Peacock and Parrot expect table based layout and will reload a single row after create / update

        # Rendering Paths
        view_path: "dhatu/photo_albums",
        js_view_path: "/kuppayam/workflows/nested_folders",
        # js_view_path: "/kuppayam/workflows/default",

        # Additional Configurations
        load_rich_text_editor: false,
        tagsinput: false
      }
    end

    def configure_filter_ui_settings
      @filter_ui_settings = {}
    end

    def breadcrumbs_configuration
      {
        heading: "Manage Photo Albums",
        icon: "fa-image",
        description: "Listing all Photo Albums",
        links: [{name: "Home", link: breadcrumb_home_path, icon: 'fa-home'}, 
                  {name: "Manage Photo Albums", link: dhatu.photo_albums_path, icon: 'fa-image', active: true}]
      }
    end

    def permitted_params
      params.require("dhatu/photo_album").permit(:name, :code, :one_liner, :description, :priority, :parent_id, :category_type)
    end
    

  end
end
