module Dhatu
  class PromotionsController < ResourceController

    private

    def permitted_params
      params.require("dhatu/promotion").permit(:title, :short_description, :display_name, :display_email, :display_phone, :name_mandatory, :email_mandatory, :phone_mandatory, :show_popup, :show_only_on_homepage, :popup_lifespan_in_minutes)
    end

    def get_resource
      @promotion = @r_object = @resource_options[:class].find_by_id(params[:id])
      @promotion_attributes = @promotion.promotion_attributes.page(@current_page).per(@per_page)
    end

    def get_collections
      @relation = Dhatu::Promotion.includes(:cover_image).where("")
      params[:st] = "published" if params[:st].nil?
      parse_filters
      apply_filters
      @promotions = @r_objects = @relation.page(@current_page).per(@per_page)
      return true
    end

    def apply_filters
      @relation = @relation.search(@query) if @query
      @relation = @relation.status(@status) if @status
      @relation = @relation.order("priority ASC, title ASC")
    end

    def configure_filter_settings
      @filter_settings = {
        string_filters: [
          { filter_name: :query },
          { filter_name: :status }
        ],

        boolean_filters: [],

        reference_filters: [],
        variable_filters: [],
      }
    end

    def configure_filter_ui_settings
      @filter_ui_settings = {
        status: {
          object_filter: false,
          select_label: "Filter by Status",
          display_hash: Dhatu::Promotion::STATUS,
          current_value: @status,
          values: Dhatu::Promotion::STATUS_REVERSE,
          current_filters: @filters,
          filters_to_remove: [],
          filters_to_add: {},
          url_method_name: 'promotions_url',
          show_all_filter_on_top: true
        }
      }
    end

    def resource_controller_configuration
      {
        page_title: "Promotions",
        js_view_path: "/kuppayam/workflows/peacock",
        view_path: "dhatu/promotions",
        collection_name: :promotions,
        item_name: :promotion,
        class: Dhatu::Promotion,
      }
      {
        page_title: "Manage Promotions",
        current_nav: "dhatu/promotions",

        # Resource Names
        class: Dhatu::Promotion,
        collection_name: :promotions,
        item_name: :promotion,
        
        # Conditions
        get_collections_after_save_resource: false,
        show_modal_after_create: true,
        show_modal_after_update: true,

        # Model Size can be large or generic
        form_model_size: :large,
        show_model_size: :large,

        # Layout can be table or feed
        # table uses html tables and feed uses div based boxes
        layout: :table,

        # "/kuppayam/workflows/default"
        # 
        # Default partial opens show and form partial according to the model_size configuration
        # It also respect the configuration layout and refresh the page element on both cases - i.e layout is table or feed

        # "/kuppayam/workflows/peacock"
        # "/kuppayam/workflows/parrot"
        # 
        # Peacock & Parrot are old ways of doing things and it respects certail configurations
        # Peacock opens show and form partials in large popup where as Parrot opens it in small
        # Both Peacock and Parrot expect table based layout and will reload a single row after create / update

        #
        checkbox_fields: [:name_mandatory, :email_mandatory, :phone_mandatory, :show_popup, :show_only_on_homepage],

        # Rendering Paths
        view_path: "dhatu/promotions",
        js_view_path: "/kuppayam/workflows/default",

        # Additional Configurations
        load_rich_text_editor: true,
        tagsinput: false
      }
    end

    def breadcrumbs_configuration
      {
        heading: "Manage Promotions",
        icon: "fa-gift",
        description: "Listing all Promotions",
        links: [{name: "Dashboard", link: breadcrumb_home_path, icon: 'fa-dashboard'}, 
                  {name: "Manage Promotions", link: dhatu.promotions_path, icon: 'fa-gift', active: true}]
      }
    end

    def set_navs
      set_nav("dhatu/promotions")
    end

  end
end
