class Dhatu::Page < Dhatu::ApplicationRecord

  # Set Table Name
  self.table_name = "pages"

  # Including the State Machine Methods
  include Publishable

  # Validations
  validates :name, presence: true, length: {minimum: 3, maximum: 64}, allow_blank: false
  validates :code, presence: true, length: {minimum: 3, maximum: 64}, allow_blank: false
  
  # Associations
  belongs_to :feature, optional: true

  # Meta Tag Associations
  has_one :og_image, :as => :imageable, :dependent => :destroy, :class_name => "Image::OgImage"
  has_many :meta_tags, :as => :meta_taggable, :dependent => :destroy, :class_name => "Dhatu::MetaTag"
  has_many :sections, class_name: "Dhatu::Section"
  
  # ------------------
  # Class Methods
  # ------------------

  scope :search, lambda { |query| where("LOWER(name) LIKE LOWER('%#{query}%') OR LOWER(code) LIKE LOWER('%#{query}%')") }

  def self.save_row_data(hsh)
    # Initializing error hash for displaying all errors altogether
    error_object = Kuppayam::Importer::ErrorHash.new

    return error_object if hsh[:code].to_s.strip.blank?

    page = Dhatu::Page.where("code = ?", hsh[:code].to_s.strip).first || Dhatu::Page.new

    page.name = hsh[:name].to_s.strip
    page.code = hsh[:code].to_s.strip

    page.feature = Feature.where("name = ?", hsh[:feature].to_s.strip).first

    page.status = hsh[:status].to_s.strip || PUBLISHED
    page.priority = hsh[:priority].to_s.strip || 1

    if page.valid?
      begin
        page.save!
      rescue Exception => e
        summary = "uncaught #{e} exception while handling connection: #{e.message}"
        details = "Stack trace: #{e.backtrace.map {|l| "  #{l}\n"}.join}"
        error_object.errors << { summary: summary, details: details }        
      end
    else
      summary = "Error while saving page: #{page.title}"
      details = "Error! #{page.errors.full_messages.to_sentence}"
      error_object.errors << { summary: summary, details: details }
    end
    return error_object
  end

  # ------------------
  # Instance Methods
  # ------------------

  # Generic Methods
  # ---------------

  def display_name
    "#{self.name_was} - #{self.code}"
  end

  # Permission Methods
  # ------------------

  def can_be_edited?
    status?(:published) or status?(:unpublished)
  end

  def can_be_deleted?
    return false if self.sections.count > 0
    status?(:removed)
  end
  
end
